authentication library

Classes

AbstractAuthentication
BCrypt
BCrypt implements OpenBSD-style Blowfish password hashing using the scheme described in "A Future-Adaptable Password Scheme" by Niels Provos and David Mazieres.
BcryptPbkdf
CraAuthentication
WAMP-CRA authentication implementation (client & router shared).
CryptosignAuthentication
Pem
Pkcs8
Ppk
PpkMacData
ScramAuthentication
WAMP-SCRAM authentication with asynchronous password-key derivation.
ScramKeyCacheBinding
Exact derivation inputs that bind a reusable SCRAM client/server key pair.
ScramKeyDerivationRequest
Inputs for a single SCRAM password-key derivation.
ScramKeyDerivationTask
A running key derivation that can be terminated independently.
ScramKeyDeriver
Runs expensive SCRAM key derivation away from the caller's event loop.
ScramServerSecrets
TicketAuthentication
Ticket-based authentication implementation shared by client and router.

Enums

AuthenticationStringEncoding
Controls how authentication strings are converted to bytes.