ConnectanumHttpAuthTokenKind enum

Selects the credential revoked by a grant-aware HTTP-auth operation.

Inheritance
Available extensions

Values

accessToken → const ConnectanumHttpAuthTokenKind
const ConnectanumHttpAuthTokenKind('access_token')
refreshToken → const ConnectanumHttpAuthTokenKind
const ConnectanumHttpAuthTokenKind('refresh_token')

Properties

hashCode int
The hash code for this object.
no setterinherited
hint String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectanumHttpAuthTokenKind>
A constant List of the values in this enum, in order of their declaration.