McpProtectedResourceMetadata class final

Validated OAuth Protected Resource Metadata for an MCP HTTP endpoint.

Properties

authorizationServers → List<Uri>
final
bearerMethodsSupported → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
raw → Map<String, Object?>
final
resource → Uri
final
resourceName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopesSupported → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited