authentication library
Classes
- AbstractAuthentication
- CraAuthentication
- This is the WAMPCRA authentication implementation for this package. Use it with the Client.
- CryptosignAuthentication
- ScramAuthentication
- This class enables SCRAM authentication process with PBKDF2 as key derivation function
- TicketAuthentication
- This is the ticket based authentication implementation for this package. Use it with the Client.
Enums
- AuthenticationStringEncoding
- Controls how auth strings are converted to bytes during key derivation and signature calculation.